Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2272)

Unified Diff: chrome/browser/ui/views/location_bar/keyword_hint_view.h

Issue 2803693007: Adjust appearance of omnibox keyword hint view for on-screen keyboards. (Closed)
Patch Set: self review Created 3 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/location_bar/keyword_hint_view.h
diff --git a/chrome/browser/ui/views/location_bar/keyword_hint_view.h b/chrome/browser/ui/views/location_bar/keyword_hint_view.h
index c4628c2944f644531043e44a91f1a918d6259fb3..ade8ff0c5705fc87059485284df6789f858f2b6b 100644
--- a/chrome/browser/ui/views/location_bar/keyword_hint_view.h
+++ b/chrome/browser/ui/views/location_bar/keyword_hint_view.h
@@ -36,8 +36,8 @@ class KeywordHintView : public views::CustomButton {
KeywordHintView(views::ButtonListener* listener,
Profile* profile,
const gfx::FontList& font_list,
- const gfx::FontList& bubble_font_list,
- int tab_key_height,
+ const gfx::FontList& chip_font_list,
+ int chip_height,
SkColor text_color,
SkColor background_color);
~KeywordHintView() override;
@@ -60,11 +60,11 @@ class KeywordHintView : public views::CustomButton {
Profile* profile_;
views::Label* leading_label_;
- views::View* tab_key_view_;
+ views::Label* chip_view_;
views::Label* trailing_label_;
- // Height of the tab key view.
- int tab_key_height_;
+ // Height of the chip/chip view.
Peter Kasting 2017/04/07 18:14:15 Nit: Is this a typo, or is "chip" different from "
Evan Stade 2017/04/08 00:07:22 yea that's a typo. Should be able to just remove i
+ int chip_view_height_;
base::string16 keyword_;

Powered by Google App Engine
This is Rietveld 408576698